@@ -1,7 +1,7 @@
 import os
 import json
 import hashlib
-G_version = "2.0.3"
+G_version = "2.0.4"
 G_auth_server = "http://192.168.12.81:8888/"
 G_secure_access = True
 
@@ -17,7 +17,8 @@ else:
     # create default password
     with open(authfile, "w") as f:
         md5 = hashlib.md5("123456".encode("ascii"))
-        authorization = {"password": md5.hexdigest()}
+        G_password = md5.hexdigest()
+        authorization = {"password": G_password}
         json.dump(authorization, f)
 
 def get_password():
